function [mini, medh] = localMinPet(spectrum, window, rightWindow, mono)
% localMinPet(spectrum, leftWindow, rightWindow, mono)
%
% Arguments are a spectrum, optional window sizes that scale
% quadratically from the left window to the right window, and
% an optional flag to tell us if the baseline should be
% monotonically decreasing. Default window sizes both equal 100.
% Default value of mono = 0, meaning 
%
% Part of the SPF, SPDBC package described in Clinical Chemistry 2003; 49:1615-1623.
%
% Original version by Kevin Coombes
% $Revision: 2.2 $
% Last modified by $Author: krc $ on $Date: 2003/03/31 19:01:57 $.

if nargin < 2,
   window = 100;
end
if nargin < 3,
   rightWindow = window;
end
if nargin < 4
   mono = 0;
end

len = length(spectrum);
tops = 1:len;
a = (rightWindow-window)./len^2;		% define "close" using y = a*x^2 + b
resolve = floor(window + (a.*tops).*tops);	% using window parameters.

% compute the local minima in the windows. Edge effects to avoid running
% off the ends of the array.
mini = zeros(len, 1);
medh = zeros(len, 1);
lend = max(1, tops-resolve);
rend = min(len, tops + resolve);
for i = 1:len,
   s = spectrum(lend(i):rend(i));
   mini(i) = min(s);
   medh(i) = median(s-mini(i));
end;

% monotonize
if mono > 0,
   mono = zeros(len, 1);
   mono(1) = mini(1);
   for i = 2:len,
      mono(i) = mono(i-1);
      if mini(i) < mono(i),
         mono(i) = mini(i);
      end
   end
   mini=mono;
end

